@@ -19,7 +19,7 @@
 #   Craig Barratt <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2006  Craig Barratt
+#   Copyright (C) 2001-2007  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@
 #
 #========================================================================
 #
-# Version 3.0.0, released 28 Jan 2007.
+# Version 3.1.0, released 25 Nov 2007.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -72,7 +72,7 @@ BackupPC cannot load the package $pkg, which is included in the
 BackupPC distribution.  This probably means you did not cd to the
 unpacked BackupPC distribution before running configure.pl, eg:
 
-    cd BackupPC-3.0.0
+    cd BackupPC-3.1.0
     ./configure.pl
 
 Please try again.
@@ -474,7 +474,7 @@ if ( $Conf{CgiDir} ne "" ) {
 
 BackupPC's CGI script needs to display various GIF images that
 should be stored where Apache can serve them.  They should be
-placed somewher under Apache's DocumentRoot.  BackupPC also
+placed somewhere under Apache's DocumentRoot.  BackupPC also
 needs to know the URL to access these images.  Example:
 
     Apache image directory:  /usr/local/apache/htdocs/BackupPC
@@ -578,6 +578,7 @@ foreach my $prog ( qw(
         bin/BackupPC
         bin/BackupPC_archive
         bin/BackupPC_archiveHost
+        bin/BackupPC_archiveStart
         bin/BackupPC_attribPrint
         bin/BackupPC_dump
         bin/BackupPC_fixupBackupSummary
@@ -635,7 +636,9 @@ foreach my $lib ( qw(
         lib/BackupPC/Lang/fr.pm
         lib/BackupPC/Lang/it.pm
         lib/BackupPC/Lang/nl.pm
+        lib/BackupPC/Lang/pl.pm
         lib/BackupPC/Lang/pt_br.pm
+        lib/BackupPC/Lang/zh_CN.pm
         lib/BackupPC/Storage/Text.pm
         lib/BackupPC/Xfer/Archive.pm
         lib/BackupPC/Xfer/BackupPCd.pm
@@ -659,7 +662,7 @@ if ( $Conf{CgiImageDir} ne "" ) {
     #
     # Install new CSS file, making a backup copy if necessary
     #
-    my $cssBackup = "$DestDir$Conf{CgiImageDir}/BackupPC_stnd.css.pre-3.0.0";
+    my $cssBackup = "$DestDir$Conf{CgiImageDir}/BackupPC_stnd.css.pre-3.1.0";
     if ( -f "$DestDir$Conf{CgiImageDir}/BackupPC_stnd.css" && !-f $cssBackup ) {
 	rename("$DestDir$Conf{CgiImageDir}/BackupPC_stnd.css", $cssBackup);
     }
@@ -667,12 +670,14 @@ if ( $Conf{CgiImageDir} ne "" ) {
 	        "$DestDir$Conf{CgiImageDir}/BackupPC_stnd.css", 0444, 0);
     InstallFile("conf/BackupPC_stnd_orig.css",
 	        "$DestDir$Conf{CgiImageDir}/BackupPC_stnd_orig.css", 0444, 0);
+    InstallFile("conf/sorttable.js",
+                "$DestDir$Conf{CgiImageDir}/sorttable.js", 0444, 0);
 }
 
 printf("Making init.d scripts\n");
 foreach my $init ( qw(gentoo-backuppc gentoo-backuppc.conf linux-backuppc
-		      solaris-backuppc debian-backuppc suse-backuppc
-		      slackware-backuppc ) ) {
+		      solaris-backuppc debian-backuppc freebsd-backuppc
+                      suse-backuppc slackware-backuppc ) ) {
     InstallFile("init.d/src/$init", "init.d/$init", 0444);
 }
 
@@ -773,6 +778,13 @@ $Conf{CgiNavBarAdminAllHosts} = 1;
 #
 $Conf{IncrFill} = 0;
 
+#
+# Empty $Conf{ParPath} if it isn't a valid executable
+# (pre-3.0.0 configure.pl incorrectly set it to a
+# hardcoded value).
+#
+$Conf{ParPath} = '' if ( $Conf{ParPath} ne '' && !-x $Conf{ParPath} );
+
 #
 # Figure out sensible arguments for the ping command
 #
@@ -848,7 +860,7 @@ if ( defined($Conf{CgiUserConfigEdit}) ) {
 #
 # Now backup and write the config file
 #
-my $confCopy = "$dest.pre-3.0.0";
+my $confCopy = "$dest.pre-3.1.0";
 if ( -f $dest && !-f $confCopy ) {
     #
     # Make copy of config file, preserving ownership and modes
@@ -1339,7 +1351,7 @@ Craig Barratt <cbarratt@users.sourceforge.net>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2001-2006  Craig Barratt.
+Copyright (C) 2001-2007  Craig Barratt.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
