@@ -10,7 +10,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2003  Craig Barratt
+#   Copyright (C) 2003-2007  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 3.0.0, released 28 Jan 2007.
+# Version 3.1.0, released 25 Nov 2007.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -45,7 +45,7 @@ sub action
        $strNone, $strGood, $hostCntGood, $hostCntNone);
 
     $hostCntGood = $hostCntNone = 0;
-    GetStatusInfo("hosts");
+    GetStatusInfo("hosts info");
     my $Privileged = CheckPermission();
 
     foreach my $host ( GetUserHosts(1) ) {
@@ -136,18 +136,18 @@ sub action
 	}
 
         $str = <<EOF;
-<tr$reasonHilite><td class="border"> ${HostLink($host)} </td>
+<tr$reasonHilite><td class="border">${HostLink($host)}</td>
     <td align="center" class="border"> ${UserLink(defined($Hosts->{$host})
 				    ? $Hosts->{$host}{user} : "")} </td>
-    <td align="center" class="border"> $fullCnt </td>
-    <td align="center" class="border"> $fullAge </td>
-    <td align="center" class="border"> $fullSize </td>
-    <td align="center" class="border"> $fullRate </td>
-    <td align="center" class="border"> $incrCnt </td>
-    <td align="center" class="border"> $incrAge </td>
-    <td align="center" class="border"> $lastAge </td> 
-    <td align="center" class="border"> $Lang->{$tempState} </td>
-    <td class="border"> $Lang->{$tempReason}$shortErr </td></tr>
+    <td align="center" class="border">$fullCnt</td>
+    <td align="center" class="border">$fullAge</td>
+    <td align="center" class="border">$fullSize</td>
+    <td align="center" class="border">$fullRate</td>
+    <td align="center" class="border">$incrCnt</td>
+    <td align="center" class="border">$incrAge</td>
+    <td align="center" class="border">$lastAge</td> 
+    <td align="center" class="border">$Lang->{$tempState}</td>
+    <td class="border">$Lang->{$tempReason}$shortErr</td></tr>
 EOF
         if ( @Backups == 0 ) {
             $hostCntNone++;
@@ -160,6 +160,8 @@ EOF
     $fullSizeTot = sprintf("%.2f", $fullSizeTot / 1000);
     $incrSizeTot = sprintf("%.2f", $incrSizeTot / 1000);
     my $now      = timeStamp2(time);
+    my $DUlastTime   = timeStamp2($Info{DUlastValueTime});
+    my $DUmaxTime    = timeStamp2($Info{DUDailyMaxTime});
 
     my $content = eval ("qq{$Lang->{BackupPC_Summary}}");
     Header($Lang->{BackupPC__Server_Summary}, $content);
